package com.jqtx.windows.command;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.lang.Assert;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.jqtx.windows.common.exception.BizException;
import com.jqtx.windows.common.factory.AbstractCommand;
import com.jqtx.windows.common.factory.RuntimeContextHolder;
import com.jqtx.windows.component.CreditComponent;
import com.jqtx.windows.component.LoanComponent;
import com.jqtx.windows.component.enums.CreditResultStatusEnum;
import com.jqtx.windows.component.enums.ZNPostUrlEnum;
import com.jqtx.windows.component.model.CreditModel;
import com.jqtx.windows.component.model.LoanCreditSubmitModel;
import com.jqtx.windows.component.model.LoanModel;
import com.jqtx.windows.infrastructure.enums.ExceptionCodeEnum;
import com.jqtx.windows.infrastructure.feign.IWakandaFeignService;
import com.jqtx.windows.utils.AbcHttpClient;
import com.jqtx.windows.web.response.JsonResult;
import com.jqtx.windows.web.response.LoanSubmitResponse;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.time.LocalDateTime;
import java.util.Objects;

/**
 * 提现授信审核
 */
@Service
@Slf4j
public class LoanSubmitCommand extends AbstractCommand {

    @Autowired
    private LoanComponent loanComponent;
    @Autowired
    private CreditComponent creditComponent;
    @Autowired
    private IWakandaFeignService wakandaFeignService;

    @Autowired
    private AbcHttpClient abcHttpClient;

    @Override
    public JsonResult execute() {
        String request = RuntimeContextHolder.currentRuntimeContext().getRequestBody();
        LoanSubmitResponse loanSubmitResponse = JSON.parseObject(request, LoanSubmitResponse.class);
        CreditModel creditModel = creditComponent.getByOrderNo(loanSubmitResponse.getOrderNo());
        if (Objects.isNull(creditModel)) {
            throw new BizException(ExceptionCodeEnum.BIZ_CREDIT_NOT_FOUND_ERROR);
        }
        //查询loan表是否存在
        LoanModel loanComponentByLoanNo = loanComponent.getByLoanNo(loanSubmitResponse.getLoanNo());
        Assert.isFalse(loanComponentByLoanNo != null, "重新借款单");

        // 保存windows_loan表
        LoanModel loanModel = new LoanModel();
        loanModel.setOrderNo(loanSubmitResponse.getOrderNo());
        loanModel.setLoanNo(loanSubmitResponse.getLoanNo());
        loanModel.setLoanStatus(CreditResultStatusEnum.INIT.name());
        loanModel.setGmtCreated(LocalDateTime.now());
        loanModel.setGmtModified(LocalDateTime.now());
        Boolean insert = loanComponent.insert(loanModel);
        if (!insert) {
            throw new BizException(ExceptionCodeEnum.SYSTEM_SQL_INSERT_ERROR);
        }

        JSONObject thirdCredit = new JSONObject();
        thirdCredit.put("reqNo", loanSubmitResponse.getOrderNo());
        thirdCredit.put("type", "01");
        abcHttpClient.postRequest(thirdCredit.toJSONString(), ZNPostUrlEnum.CREDIT_APPLY.getCode());
        CreditModel creditModel1=new CreditModel();
        creditModel1.setCreditThirdStatus("INIT");
        creditComponent.updateByOrderNo(loanSubmitResponse.getOrderNo(),creditModel1);
        // 提现授信
        LoanCreditSubmitModel model = new LoanCreditSubmitModel();
        model.setOrderNo(loanSubmitResponse.getOrderNo());
        JsonResult<Boolean> booleanJsonResult = wakandaFeignService.loanCredit(model);
        return JsonResult.success(booleanJsonResult.isSuccess());
    }
}
